"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Menu = exports.MenuContext = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _getContainerStyles = require("./utils/getContainerStyles");

var _hooks = require("../../../hooks");

var _utils = require("../../../theme/tools/utils");

var _native = _interopRequireDefault(require("styled-components/native"));

var _styledSystem = require("styled-system");

var _customProps = require("../../../utils/customProps");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const STATES = {
  HIDDEN: 'HIDDEN',
  ANIMATING: 'ANIMATING',
  SHOWN: 'SHOWN'
};
const animationDuration = 300;

const EASING = _reactNative.Easing.bezier(0.4, 0, 0.2, 1);

const MenuContext = /*#__PURE__*/_react.default.createContext({
  open: false,
  closeMenu: () => {}
});

exports.MenuContext = MenuContext;
const StyleAnimatedView = (0, _native.default)(_reactNative.Animated.View)(_styledSystem.color, _styledSystem.space, _styledSystem.layout, _styledSystem.flexbox, _styledSystem.border, _styledSystem.typography, _customProps.customBorder, _customProps.customBackground, _customProps.customOutline, _customProps.customShadow, _customProps.customExtra, _customProps.customTypography, _customProps.customLayout);

class MenuClass extends _react.default.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "_container", null);

    _defineProperty(this, "_onMenuLayout", e => {
      if (this.state.menuState === STATES.ANIMATING) {
        return;
      }

      const {
        width,
        height
      } = e.nativeEvent.layout;
      this.setState({
        menuState: STATES.ANIMATING,
        menuWidth: width,
        menuHeight: height
      }, () => {
        _reactNative.Animated.parallel([_reactNative.Animated.timing(this.state.menuSizeAnimation, {
          toValue: {
            x: width,
            y: height
          },
          duration: _reactNative.Platform.OS === 'ios' ? animationDuration : 10,
          easing: _reactNative.Easing.bezier(0.01, 1.3, 0.77, 0.91),
          useNativeDriver: _reactNative.Platform.OS !== 'web'
        }), _reactNative.Animated.timing(this.state.opacityAnimation, {
          toValue: 1,
          duration: animationDuration,
          easing: EASING,
          useNativeDriver: _reactNative.Platform.OS !== 'web'
        })]).start();
      });
    });

    _defineProperty(this, "show", () => {
      if (this._container) {
        // @ts-ignore
        this._container.measureInWindow((left, top, buttonWidth, buttonHeight) => {
          this.setState({
            buttonHeight,
            buttonWidth,
            left,
            menuState: STATES.SHOWN,
            top
          });
        });
      }
    });

    _defineProperty(this, "hide", onHidden => {
      _reactNative.Animated.timing(this.state.opacityAnimation, {
        toValue: 0,
        duration: animationDuration,
        easing: EASING,
        useNativeDriver: _reactNative.Platform.OS !== 'web'
      }).start(() => {
        this.setState({
          menuState: STATES.HIDDEN,
          menuSizeAnimation: new _reactNative.Animated.ValueXY({
            x: 0,
            y: 0
          }),
          opacityAnimation: new _reactNative.Animated.Value(0)
        }, () => {
          if (onHidden) {
            onHidden();
          }

          if (_reactNative.Platform.OS !== 'ios' && this.props.onClose) {
            this.props.onClose();
          }
        });
      });
    });

    _defineProperty(this, "_hide", () => {
      this.hide();
    });

    this.state = {
      open: false,
      menuState: STATES.HIDDEN,
      top: 0,
      left: 0,
      menuWidth: 0,
      menuHeight: 0,
      buttonWidth: 0,
      buttonHeight: 0,
      menuSizeAnimation: new _reactNative.Animated.ValueXY({
        x: 0,
        y: 0
      }),
      opacityAnimation: new _reactNative.Animated.Value(0)
    };
  }

  render() {
    const {
      menuSizeAnimation,
      menuWidth,
      menuHeight,
      buttonWidth,
      buttonHeight,
      opacityAnimation
    } = this.state;
    let {
      menuSize,
      menuContainerStyle
    } = (0, _getContainerStyles.getContainerStyles)(this.state.top, this.state.left, menuSizeAnimation, menuWidth, menuHeight, buttonWidth, buttonHeight, opacityAnimation);
    const {
      menuState
    } = this.state;
    const animationStarted = menuState === STATES.ANIMATING;
    const modalVisible = menuState === STATES.SHOWN || animationStarted;
    const {
      testID,
      trigger,
      style,
      children,
      onOpen,
      onClose,
      closeOnSelect = true
    } = this.props;

    const closeMenu = () => {
      onClose && onClose();
      this.hide();
    };

    let triggerElement = trigger ? trigger({
      onPress: () => {
        if (this.state.open) {
          closeMenu();
        } else {
          this.show();
          onOpen && onOpen();
        }
      }
    }, {
      open: this.state.open
    }) : null;
    const [shadowContainerProps] = (0, _utils.extractInObject)(this.props, ['borderRadius', 'bg', 'backgroundColor', 'shadowOffset', 'shadowColor', 'elevation', 'shadowOpacity', 'shadowRadius']);
    return /*#__PURE__*/_react.default.createElement(MenuContext.Provider, {
      value: {
        open: this.state.open,
        closeMenu,
        closeOnSelect
      }
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      ref: ref => {
        this._container = ref;
      },
      collapsable: false,
      testID: testID
    }, triggerElement, /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
      visible: modalVisible,
      onRequestClose: this._hide,
      supportedOrientations: ['portrait', 'portrait-upside-down', 'landscape', 'landscape-left', 'landscape-right'],
      transparent: true
    }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
      onPress: this._hide
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: _reactNative.StyleSheet.absoluteFill
    }, /*#__PURE__*/_react.default.createElement(StyleAnimatedView, _extends({
      onLayout: this._onMenuLayout,
      position: "absolute",
      opacity: 0
    }, shadowContainerProps, {
      style: [menuContainerStyle, style]
    }), /*#__PURE__*/_react.default.createElement(StyleAnimatedView, {
      style: [animationStarted && menuSize]
    }, children)))))));
  }

}

const Menu = props => {
  const newProps = (0, _hooks.usePropsConfig)('Menu', props);
  return /*#__PURE__*/_react.default.createElement(MenuClass, newProps);
};

exports.Menu = Menu;
//# sourceMappingURL=Menu.js.map