"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getContainerStyles = getContainerStyles;

var _reactNative = require("react-native");

const SCREEN_INDENT = 0;

function getContainerStyles(top, left, menuSizeAnimation, menuWidth, menuHeight, buttonWidth, buttonHeight, opacityAnimation) {
  const {
    isRTL
  } = _reactNative.I18nManager;

  const dimensions = _reactNative.Dimensions.get('window');

  const {
    width: windowWidth
  } = dimensions;
  const windowHeight = dimensions.height - (_reactNative.StatusBar.currentHeight || 0);
  const menuSize = {
    width: menuSizeAnimation.x,
    height: menuSizeAnimation.y
  }; // Adjust position of menu

  const transforms = [];

  if (isRTL && left + buttonWidth - menuWidth > SCREEN_INDENT || !isRTL && left + menuWidth > windowWidth - SCREEN_INDENT) {
    transforms.push({
      translateX: _reactNative.Animated.multiply(menuSizeAnimation.x, -1)
    });
    left = Math.min(windowWidth, left + buttonWidth);
  } // Flip by Y axis if menu hits bottom screen border


  if (top > windowHeight - menuHeight - SCREEN_INDENT) {
    transforms.push({
      translateY: _reactNative.Animated.multiply(menuSizeAnimation.y, -1)
    });
    top = windowHeight - SCREEN_INDENT;
    top = Math.min(windowHeight - menuHeight + SCREEN_INDENT + (_reactNative.Platform.OS === 'android' ? 3 : 2) * buttonHeight, top + buttonHeight);
  }

  const menuContainerStyle = {
    opacity: opacityAnimation,
    transform: transforms,
    top,
    // Switch left to right for rtl devices
    ...(isRTL ? {
      right: left
    } : {
      left
    })
  };
  return {
    menuContainerStyle,
    menuSize
  };
}
//# sourceMappingURL=getContainerStyles.js.map