"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.PopoverCloseButton = exports.PopoverFooter = exports.PopoverBody = exports.PopoverContent = exports.PopoverHeader = exports.PopoverTrigger = void 0;

var _react = _interopRequireDefault(require("react"));

var _Tooltip = _interopRequireDefault(require("./Tooltip"));

var _native = _interopRequireDefault(require("styled-components/native"));

var _styledSystem = require("styled-system");

var _customProps = require("../../../utils/customProps");

var _primitives = require("../../primitives");

var _CloseButton = _interopRequireDefault(require("../CloseButton"));

var _hooks = require("../../../hooks");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const StyledPopover = (0, _native.default)(_Tooltip.default)(_styledSystem.color, _styledSystem.space, _styledSystem.layout, _styledSystem.flexbox, _styledSystem.border, _customProps.customBorder, _customProps.customBackground, _customProps.customOutline, _customProps.customShadow, _customProps.customExtra, _customProps.customLayout);

const PopoverContext = /*#__PURE__*/_react.default.createContext({
  PopoverTrigger: null,
  setPopoverTrigger: _child => {},
  PopoverRef: null,
  backgroundColor: '',
  borderColor: '',
  borderWidth: null,
  initialFocusRef: null,
  finalFocusRef: null,
  isVisible: false,
  setIsVisible: _bool => {},
  onOpen: () => {},
  onClose: () => {},
  closeOnBlur: true,
  newProps: {
    popoverCloseButtonStyle: {},
    popoverCloseButtonProps: {},
    popoverFooterProps: {},
    popoverBodyProps: {},
    popoverContentProps: {},
    popoverHeaderProps: {}
  }
});

const Popover = ({
  children,
  initialFocusRef,
  finalFocusRef,
  onOpen,
  onClose,
  closeOnBlur,
  id,
  backgroundColor,
  bg,
  borderWidth,
  borderColor,
  ...props
}) => {
  const [trigger, setTrigger] = _react.default.useState( /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null));

  const [isVisible, setIsVisible] = _react.default.useState(false);

  const popOverRef = _react.default.useRef(null);

  const newProps = (0, _hooks.usePropsConfig)('Popover', props);
  const value = {
    PopoverTrigger: trigger,
    setPopoverTrigger: setTrigger,
    PopoverRef: popOverRef,
    initialFocusRef: initialFocusRef,
    finalFocusRef: finalFocusRef,
    isVisible: isVisible,
    setIsVisible: setIsVisible,
    onOpen: onOpen,
    onClose: onClose,
    newProps: newProps,
    closeOnBlur: closeOnBlur,
    backgroundColor: bg || backgroundColor || { ...newProps.popoverProps
    }.backgroundColor,
    borderColor: borderColor || { ...newProps.popoverProps
    }.borderColor,
    borderWidth: borderWidth || { ...newProps.popoverProps
    }.borderWidth
  };
  return /*#__PURE__*/_react.default.createElement(PopoverContext.Provider, {
    value: value
  }, /*#__PURE__*/_react.default.createElement(_primitives.View, {
    nativeID: id
  }, children));
};

const PopoverTrigger = ({
  children
}) => {
  const {
    setPopoverTrigger
  } = _react.default.useContext(PopoverContext);

  _react.default.useEffect(() => {
    setPopoverTrigger(_react.default.Children.map(children, child => {
      return /*#__PURE__*/_react.default.cloneElement(child, {
        isDisabled: true,
        disabled: true
      }, child.props.children);
    }));
  }, [setPopoverTrigger, children]);

  return null;
};

exports.PopoverTrigger = PopoverTrigger;

const PopoverHeader = props => {
  const {
    newProps
  } = _react.default.useContext(PopoverContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.popoverHeaderProps, props));
};

exports.PopoverHeader = PopoverHeader;

const PopoverContent = ({
  children,
  ...props
}) => {
  const {
    PopoverRef,
    PopoverTrigger,
    onOpen,
    initialFocusRef,
    onClose,
    finalFocusRef,
    closeOnBlur,
    newProps,
    backgroundColor,
    borderColor,
    borderWidth
  } = _react.default.useContext(PopoverContext);

  return /*#__PURE__*/_react.default.createElement(StyledPopover, _extends({}, newProps.popoverContentProps, {
    width: newProps._width || newProps.size || '45%',
    backgroundColor: backgroundColor,
    borderColor: borderColor,
    borderWidth: borderWidth,
    ref: PopoverRef,
    onOpen: () => {
      onOpen ? onOpen() : '';
      initialFocusRef === null || initialFocusRef === void 0 ? void 0 : initialFocusRef.current.focus();
    },
    onClose: () => {
      onClose ? onClose() : '';
      finalFocusRef === null || finalFocusRef === void 0 ? void 0 : finalFocusRef.current.focus();
    },
    closeOnBlur: closeOnBlur === false ? false : true,
    popover: /*#__PURE__*/_react.default.createElement(_primitives.Box, {
      width: "100%"
    }, /*#__PURE__*/_react.default.createElement(_primitives.Box, null, children))
  }, props), PopoverTrigger);
};

exports.PopoverContent = PopoverContent;

const PopoverBody = props => {
  const {
    newProps,
    borderColor,
    borderWidth
  } = _react.default.useContext(PopoverContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.popoverBodyProps, {
    borderTopColor: borderColor,
    borderTopWidth: borderWidth
  }, props));
};

exports.PopoverBody = PopoverBody;

const PopoverFooter = props => {
  const {
    newProps,
    borderColor,
    borderWidth
  } = _react.default.useContext(PopoverContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.popoverFooterProps, {
    borderTopColor: borderColor,
    borderTopWidth: borderWidth
  }, props));
};

exports.PopoverFooter = PopoverFooter;

const PopoverCloseButton = props => {
  const {
    PopoverRef,
    newProps
  } = _react.default.useContext(PopoverContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.View, {
    style: newProps.popoverCloseButtonStyle
  }, /*#__PURE__*/_react.default.createElement(_CloseButton.default, _extends({}, newProps.popoverCloseButtonProps, props, {
    onPress: () => {
      PopoverRef === null || PopoverRef === void 0 ? void 0 : PopoverRef.current.toggleTooltip();
    }
  })));
};

exports.PopoverCloseButton = PopoverCloseButton;
var _default = Popover;
exports.default = _default;
//# sourceMappingURL=index.js.map