import React from 'react';
export const ColorModeContext = /*#__PURE__*/React.createContext({});
export function ColorModeProvider(props) {
  const {
    value,
    children,
    options: {
      initialColorMode
    },
    colorModeManager
  } = props;
  const [colorMode, rawSetColorMode] = React.useState(colorModeManager ? colorModeManager.get(initialColorMode) : initialColorMode);
  const setColorMode = React.useCallback(val => {
    if (colorModeManager) {
      colorModeManager.set(val);
    }

    rawSetColorMode(val);
  }, [colorModeManager]);
  const toggleColorMode = React.useCallback(() => {
    setColorMode(colorMode === 'light' ? 'dark' : 'light');
  }, [colorMode, setColorMode]);
  const context = {
    colorMode: value !== null && value !== void 0 ? value : colorMode,
    toggleColorMode: value ? () => {} : toggleColorMode,
    setColorMode: value ? () => {} : setColorMode
  };
  return /*#__PURE__*/React.createElement(ColorModeContext.Provider, {
    value: context
  }, children);
}
export const useColorMode = () => {
  const context = React.useContext(ColorModeContext);

  if (context === undefined) {
    throw new Error('useColorMode must be used within a ColorModeProvider');
  }

  return context;
};
export function useColorModeValue(light, dark) {
  const {
    colorMode
  } = useColorMode();
  return colorMode === 'light' ? light : dark;
}
//# sourceMappingURL=provider.js.map