function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { Animated, Easing, Modal, Platform, StyleSheet, TouchableWithoutFeedback, View } from 'react-native';
import { getContainerStyles } from './utils/getContainerStyles';
import { usePropsConfig } from '../../../hooks';
import { extractInObject } from '../../../theme/tools/utils';
import styled from 'styled-components/native';
import { border, color, flexbox, layout, space, typography } from 'styled-system';
import { customBorder, customBackground, customOutline, customLayout, customExtra, customShadow, customTypography } from '../../../utils/customProps';
const STATES = {
  HIDDEN: 'HIDDEN',
  ANIMATING: 'ANIMATING',
  SHOWN: 'SHOWN'
};
const animationDuration = 300;
const EASING = Easing.bezier(0.4, 0, 0.2, 1);
export const MenuContext = /*#__PURE__*/React.createContext({
  open: false,
  closeMenu: () => {}
});
const StyleAnimatedView = styled(Animated.View)(color, space, layout, flexbox, border, typography, customBorder, customBackground, customOutline, customShadow, customExtra, customTypography, customLayout);

class MenuClass extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "_container", null);

    _defineProperty(this, "_onMenuLayout", e => {
      if (this.state.menuState === STATES.ANIMATING) {
        return;
      }

      const {
        width,
        height
      } = e.nativeEvent.layout;
      this.setState({
        menuState: STATES.ANIMATING,
        menuWidth: width,
        menuHeight: height
      }, () => {
        Animated.parallel([Animated.timing(this.state.menuSizeAnimation, {
          toValue: {
            x: width,
            y: height
          },
          duration: Platform.OS === 'ios' ? animationDuration : 10,
          easing: Easing.bezier(0.01, 1.3, 0.77, 0.91),
          useNativeDriver: Platform.OS !== 'web'
        }), Animated.timing(this.state.opacityAnimation, {
          toValue: 1,
          duration: animationDuration,
          easing: EASING,
          useNativeDriver: Platform.OS !== 'web'
        })]).start();
      });
    });

    _defineProperty(this, "show", () => {
      if (this._container) {
        // @ts-ignore
        this._container.measureInWindow((left, top, buttonWidth, buttonHeight) => {
          this.setState({
            buttonHeight,
            buttonWidth,
            left,
            menuState: STATES.SHOWN,
            top
          });
        });
      }
    });

    _defineProperty(this, "hide", onHidden => {
      Animated.timing(this.state.opacityAnimation, {
        toValue: 0,
        duration: animationDuration,
        easing: EASING,
        useNativeDriver: Platform.OS !== 'web'
      }).start(() => {
        this.setState({
          menuState: STATES.HIDDEN,
          menuSizeAnimation: new Animated.ValueXY({
            x: 0,
            y: 0
          }),
          opacityAnimation: new Animated.Value(0)
        }, () => {
          if (onHidden) {
            onHidden();
          }

          if (Platform.OS !== 'ios' && this.props.onClose) {
            this.props.onClose();
          }
        });
      });
    });

    _defineProperty(this, "_hide", () => {
      this.hide();
    });

    this.state = {
      open: false,
      menuState: STATES.HIDDEN,
      top: 0,
      left: 0,
      menuWidth: 0,
      menuHeight: 0,
      buttonWidth: 0,
      buttonHeight: 0,
      menuSizeAnimation: new Animated.ValueXY({
        x: 0,
        y: 0
      }),
      opacityAnimation: new Animated.Value(0)
    };
  }

  render() {
    const {
      menuSizeAnimation,
      menuWidth,
      menuHeight,
      buttonWidth,
      buttonHeight,
      opacityAnimation
    } = this.state;
    let {
      menuSize,
      menuContainerStyle
    } = getContainerStyles(this.state.top, this.state.left, menuSizeAnimation, menuWidth, menuHeight, buttonWidth, buttonHeight, opacityAnimation);
    const {
      menuState
    } = this.state;
    const animationStarted = menuState === STATES.ANIMATING;
    const modalVisible = menuState === STATES.SHOWN || animationStarted;
    const {
      testID,
      trigger,
      style,
      children,
      onOpen,
      onClose,
      closeOnSelect = true
    } = this.props;

    const closeMenu = () => {
      onClose && onClose();
      this.hide();
    };

    let triggerElement = trigger ? trigger({
      onPress: () => {
        if (this.state.open) {
          closeMenu();
        } else {
          this.show();
          onOpen && onOpen();
        }
      }
    }, {
      open: this.state.open
    }) : null;
    const [shadowContainerProps] = extractInObject(this.props, ['borderRadius', 'bg', 'backgroundColor', 'shadowOffset', 'shadowColor', 'elevation', 'shadowOpacity', 'shadowRadius']);
    return /*#__PURE__*/React.createElement(MenuContext.Provider, {
      value: {
        open: this.state.open,
        closeMenu,
        closeOnSelect
      }
    }, /*#__PURE__*/React.createElement(View, {
      ref: ref => {
        this._container = ref;
      },
      collapsable: false,
      testID: testID
    }, triggerElement, /*#__PURE__*/React.createElement(Modal, {
      visible: modalVisible,
      onRequestClose: this._hide,
      supportedOrientations: ['portrait', 'portrait-upside-down', 'landscape', 'landscape-left', 'landscape-right'],
      transparent: true
    }, /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
      onPress: this._hide
    }, /*#__PURE__*/React.createElement(View, {
      style: StyleSheet.absoluteFill
    }, /*#__PURE__*/React.createElement(StyleAnimatedView, _extends({
      onLayout: this._onMenuLayout,
      position: "absolute",
      opacity: 0
    }, shadowContainerProps, {
      style: [menuContainerStyle, style]
    }), /*#__PURE__*/React.createElement(StyleAnimatedView, {
      style: [animationStarted && menuSize]
    }, children)))))));
  }

}

export const Menu = props => {
  const newProps = usePropsConfig('Menu', props);
  return /*#__PURE__*/React.createElement(MenuClass, newProps);
};
//# sourceMappingURL=Menu.js.map